# Python CLI and SDK for Continual

Continual is lifecycle management for AI. Learn more at https://continual.ai.

## Getting Started

To install the Continual AI CLI and SDK run:

```
pip3 install continual
```
